@@ -1,3 +1,7 @@
+"""nfs mongodb manager
+
+mongodb 를 manage 하는 클래스 모음
+"""
 import datetime
 import math
 import re
@@ -7,6 +11,7 @@ from util_hj3415 import utils
 from .setting import load as load_setting
 from collections import OrderedDict
 import logging
+from typing import Tuple
 
 logger = logging.getLogger(__name__)
 formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
@@ -17,6 +22,10 @@ logger.setLevel(logging.WARNING)
 
 
 def chk_deactivate_mongo(func):
+    """
+    setting 모듈에서 mongo 주소 값이 ''인 경우
+    데코레이션을 통해 해당 함수를 사용하지 못하도록 하는 데코함수
+    """
     def wrapper(*args, **kwargs):
         addr = load_setting()['mongo']
         if addr == '' or addr is None:
@@ -47,14 +56,25 @@ class Base:
 
     def get_status(self) -> tuple:
         """
-        현재 설정된 (db, col)을 반환한다. - ex)('005930', 'c103재무상태표q')
+        Returns:
+            tuple: 현재 설정된 (db, col)을 반환한다.
+
+        Examples:
+            ('005930', 'c103재무상태표q')
         """
         return self.mongo_addr, self.db, self.col
 
     def chg_addr(self, addr: str):
         """
-        파일에 저장되는 세팅이 바뀌는 것이 아니라 클래스의 설명만 바뀌는 것임
-        전체 db 설정을 바꾸려면 setting.chg_mongo_addr()함수 사용할 것
+
+        현 클래스에서 참조하는 몽고디비 주소를 변경한다.
+
+        Args:
+            addr (str): mongodb://...로 시작하는 주소
+
+        Note:
+            setting 모듈을 통해 피클로 저장되는 세팅이 변하는 것이 아님
+            전체 db 설정을 바꾸려면 setting.chg_mongo_addr()함수 사용할 것
         """
         if not addr.startswith('mongodb://'):
             raise ValueError(f'Invalid mongo address : {addr}')
@@ -140,11 +160,19 @@ class Base:
 
 class MI(Base):
     """
-    mongodb에 저장된 market index를 가져오는 클래스
-    <<구조>>
-    데이터베이스 - mi
-    컬렉션 - 'aud', 'chf', 'gbond3y', 'gold', 'silver', 'kosdaq', 'kospi', 'sp500', 'usdkrw', 'wti', 'avgper', 'yieldgap', 'usdidx'
-    도큐멘트 - date, value
+
+    mi 데이터베이스 클래스
+
+    Note:
+        <<데이터베이스 구조>>\n
+        데이터베이스 - mi\n
+        컬렉션 -\n
+        'aud', 'chf', 'gbond3y',\n
+        'gold', 'silver', 'kosdaq',\n
+        'kospi', 'sp500', 'usdkrw',\n
+        'wti', 'avgper', 'yieldgap',\n
+        'usdidx' - 총 13개\n
+        도큐멘트 - date, value\n
     """
     COL_TITLE = ('aud', 'chf', 'gbond3y', 'gold', 'silver', 'kosdaq', 'kospi',
                  'sp500', 'usdkrw', 'wti', 'avgper', 'yieldgap', 'usdidx')
@@ -188,6 +216,15 @@ class MI(Base):
     # ========================특정 페이지 관련 함수들=======================
 
     def get_recent(self, index: str = '') -> dict:
+        """
+        저장된 가장 최근의 값을 반환하는 함수
+
+        Args:
+            index (str, optional): 13개의 컬렉션.
+
+        Returns:
+            dict: ex - {'date': '2021.07.26', 'value': '1047.63'}
+        """
         if index == '':
             pass
         else:
@@ -199,8 +236,10 @@ class MI(Base):
 
     def save(self, mi_dict: dict, index: str = '') -> bool:
         """
-        mi_dict의 구조 - {'date': '2021.07.21', 'value': '1154.50'}
-        index 종류 - 'aud', 'chf', 'gbond3y', 'gold', 'silver', 'kosdaq', 'kospi', 'sp500', 'usdkrw', 'wti', 'avgper', 'yieldgap', 'usdidx'
+
+        Args:
+            mi_dict (dict): ex - {'date': '2021.07.21', 'value': '1154.50'}
+            index (str, optional): 13개의 컬렉션.
         """
         if index != '':
             self.chg_index(index=index)
@@ -211,14 +250,22 @@ class MI(Base):
 
 class Corps(Base):
     """
+
     mongodb에 저장된 재무데이터를 가져오는 클래스
-    <<구조>>
-    데이터베이스 - 6자리 코드명
-    컬렉션 - c101, c103손익계산서qy, c103재무상태표qy, c103현금흐름표qy, c104qy, c106, c108, dart
-    도큐멘트참고
-        - c106은 q와 y의 2개의 도큐먼트로 구성
-        - c104는 중복되는 항목이 없어 2개의 페이지로 나눔
-        - c103는 중복되는 항목이 있어 6개의 페이지로 나눔
+
+    Note:
+    <<구조>>\n
+        데이터베이스 - 6자리 코드명\n
+        컬렉션 -\n
+        c101, c106, c108, dart\n
+        c103손익계산서qy,\n
+        c103재무상태표qy,\n
+        c103현금흐름표qy,\n
+        c104qy,\n
+        도큐멘트참고\n
+        - c106은 q와 y의 2개의 도큐먼트로 구성\n
+        - c104는 중복되는 항목이 없어 2개의 페이지로 나눔\n
+        - c103는 중복되는 항목이 있어 6개의 페이지로 나눔\n
     """
     COL_TITLE = ('c101', 'c104y', 'c104q', 'c106', 'c108',
                  'c103손익계산서q', 'c103재무상태표q', 'c103현금흐름표q',
@@ -235,7 +282,9 @@ class Corps(Base):
     # ======================Corps 만 가지는 함수들 ===========================
 
     def chg_code(self, code: str):
-        # code 가 6자리 숫자인지 확인 후 세팅
+        """
+        code 가 6자리 숫자인지 확인 후 세팅
+        """
         if utils.is_6digit(code):
             logger.info(f'Set db : {self.db} -> {code}')
             self.code = code
@@ -244,7 +293,17 @@ class Corps(Base):
             raise ValueError(f'Invalid value : {code}(6 digit)')
 
     def chg_page(self, page: str):
-        # page 가 COL_TITLE 인지 확인 후 세팅
+        """
+        page 가 COL_TITLE 인지 확인 후 세팅
+
+        Note:
+            <COL_TITLE>\n
+            'c101', 'c104y', 'c104q',\n
+            'c106', 'c108', 'dart',\n
+            'c103손익계산서qy',\n
+            'c103재무상태표qy',\n
+            'c103현금흐름표qy',\n
+        """
         if page in self.COL_TITLE:
             logger.info(f'Set col : {self.col} -> {page}')
             self.col = page
@@ -317,7 +376,18 @@ class C101(Corps):
 
     def save(self, c101_dict: dict) -> bool:
         """
+
         c101의 구조에 맞는 딕셔너리값을 받아서 구조가 맞는지 확인하고 맞으면 저장한다.
+
+        Note:
+            <c101_struc>\n
+            'date', '코드', '종목명',\n
+            '업종', '주가', '거래량',\n
+            'EPS', 'BPS', 'PER',\n
+            '업종PER', 'PBR', '배당수익률',\n
+            '최고52주', '최저52주', '거래대금',\n
+            '시가총액', '베타52주', '발행주식',\n
+            '유통비율', 'intro'\n
         """
         c101_struc = ['date', '코드', '종목명', '업종', '주가', '거래량', 'EPS', 'BPS', 'PER', '업종PER', 'PBR', '배당수익률',
                       '최고52주', '최저52주', '거래대금', '시가총액', '베타52주', '발행주식', '유통비율', 'intro']
@@ -336,7 +406,11 @@ class C101(Corps):
 
     def find(self, date: str) -> dict:
         """
-        date 입력형식 예 - 20201011(6자리숫자)
+
+        해당 날짜의 데이터를 반환한다.
+
+        Args:
+            date (str): 예 - 20201011(6자리숫자)
         """
         p = re.compile('^20[0-9][0-9][0,1][0-9][0-3][0-9]$')
         if p.match(date) is None:
@@ -351,6 +425,10 @@ class C101(Corps):
         return d
 
     def get_all(self) -> list:
+        """
+
+        저장된 모든 데이터를 딕셔너리로 가져와서 리스트로 포장하여 반환한다.
+        """
         items = []
         for doc in self.client[self.db][self.col].find({'date': {'$exists': True}}).sort('date', pymongo.ASCENDING):
             del doc['_id']
@@ -358,7 +436,11 @@ class C101(Corps):
         return items
 
     def get_recent(self) -> dict:
-        # 리턴값의 일관성을 위해서 list로 한번 포장한다.
+        """
+
+        저장된 데이터에서 가장 최근 날짜의 딕셔너리를 반환한다.
+
+        """
         d = self.client[self.db][self.col].find({'date': {'$exists': True}}).sort('date', pymongo.DESCENDING).next()
         del d['_id']
         return d
@@ -371,6 +453,10 @@ class C108(Corps):
     # ========================특정 페이지 관련 함수들=======================
 
     def get_all(self) -> list:
+        """
+
+        저장된 모든 데이터를 딕셔너리로 가져와서 리스트로 포장하여 반환한다.
+        """
         items = []
         for doc in self.client[self.db][self.col].find({'날짜': {'$exists': True}}).sort('날짜', pymongo.ASCENDING):
             del doc['_id']
@@ -378,6 +464,13 @@ class C108(Corps):
         return items
 
     def get_recent(self) -> list:
+        """
+
+        저장된 데이터에서 가장 최근 날짜의 딕셔너리를 가져와서 리스트로 포장하여 반환한다.
+
+        Returns:
+            list: 한 날짜에 c108 딕셔너리가 여러개 일수 있어서 리스트로 반환한다.
+        """
         # 저장되어 있는 데이터베이스의 최근 날짜를 찾는다.
         try:
             r_date = self.client[self.db][self.col].find({'날짜': {'$exists': True}}).sort('날짜', pymongo.DESCENDING).next()['날짜']
@@ -394,9 +487,15 @@ class C108(Corps):
 
     def save(self, c108_list: list) -> bool:
         """
-        - 인자 c108 리스트 형식
-        [{'날짜': '21/07/19', '제목': '...', '작성자': '...', '제공처': '...', '투자의견': '...', '목표가': '95,000', '내용': '...'},
-        {'날짜': '21/07/12', '제목': '...', '작성자': '김운호', '제공처': 'IBK', '투자의견': '매수', '목표가': '110,000', '내용': '...'},
+
+        Args:
+            c108_list (list): c108로 저장할 리스트 형식
+        Note:
+            c108_list 구조\n
+            [{'날짜': '21/07/19', '제목': '...',\n
+            '작성자': '...', '제공처': '...', \n
+            '투자의견': '...', '목표가': '95,000',\n
+            '내용': '...'},]\n
         """
         c108_list.append({'stamp': datetime.datetime.now()})  # c108가 리스트라서 append 사용
         # delete all documents in a collection
@@ -406,9 +505,22 @@ class C108(Corps):
 
 
 class C106(Corps):
+    """
+
+    Note:
+        내부적으로 c106 단일컬렉션에\n
+        title : c106y/q를 가지는\n
+        2개의 도큐먼트로 구성됨.\n
+    """
     PERIOD = ['q', 'y']
 
-    def __init__(self, code: str, page: str):
+    def __init__(self, code: str, page: str = 'c106y'):
+        """
+
+         Args:
+            code (str): 종목코드(디비명)
+            page (str): c106y, c106q
+        """
         if page[:4] == 'c106' and page[4:5] in self.PERIOD:
             super().__init__(code=code, page='c106')
             self.page = page
@@ -447,10 +559,17 @@ class C106(Corps):
 
     def save(self, c106_dict: dict) -> bool:
         """
-        - 인자 c106 딕셔너리 형식
-        {'전일종가': {'동화약품': '14600', '환인제약': '24700', '큐라클': '24100', '하나제약': '7600', '노바렉스': '27900'},
-        '시가총액': {'동화약품': '4078.0', '환인제약': '4039.6', '큐라클': '4260.7', '하나제약': '3811.7', '노바렉스': '4606.6'}}
-        - 각 항목이 중복되지 않는 경우라서 항목을 키로하는 딕셔너리를 인자로 받는다.
+
+        Args:
+            c106_dict (dict): c106으로 저장할 딕셔너리 형식
+
+        Example:
+            c106_dict 구조\n
+            {'전일종가': {'동화약품': '14600'..., '노바렉스': '27900'},\n
+            '시가총액': {'동화약품': '4078.0'..., '노바렉스': '4606.6'}}\n
+
+        Note:
+            각 항목이 중복되지 않는 경우라서 항목을 키로하는 딕셔너리를 인자로 받는다.
         """
         c106_dict['title'] = self.page
         c106_dict['stamp'] = datetime.datetime.now()
@@ -466,7 +585,11 @@ class C1034(Corps):
 
     def get_all_title(self) -> list:
         """
+
         중복된 타이틀을 취급하지 않기 위해 타이틀 전체에서 중복된 타이틀을 제거하고 나머지 타이틀 리스트를 반환한다.
+
+        Returns:
+            list: 중복된 항목을 제외한 모든 항목을 담은 리스트
         """
         # 항목만 추출한 리스트 만들기
         title_list = []
@@ -495,6 +618,19 @@ class C1034(Corps):
         return return_list
 
     def get_all(self) -> dict:
+        """
+
+        페이지의 모든 항목에 대한 값을 딕셔너리 형태로 반환.
+
+        Returns:
+            dict: 각 항목을 키로하고 해당 기간별 데이터를 값으로 하는 딕셔너리
+
+        Example:
+            리턴값 예시\n
+            {'*(비지배)당기순이익': {...'2020/12': 1860.0, '2021/12': nan},
+            '*(지배)당기순이익': {...'2020/12': 16021.5,'2021/12': nan},}
+
+        """
         c1034_list = self.get_all_item()
         # c104_list 내부에서는 항목, 전년/분기대비, 년/월을 포함하는 딕셔너리가 담겨있다.
         return_dict = {}
@@ -521,7 +657,18 @@ class C1034(Corps):
 
     def get_all_cmp(self) -> dict:
         """
-        전년/분기대비 값을 반환하는 함수
+
+        페이지의 모든 항목에 대한 전년/분기대비 값을 딕셔너리 형태로 반환.
+
+        Returns:
+            dict: 각 항목을 키로하고 전분기/년대비 증감 데이터를 값으로 하는 딕셔너리
+
+        Example:
+            리턴값 예시\n
+            {'*(비지배)당기순이익': 26.1,
+            '*(지배)당기순이익': -12.7,
+            '*CAPEX': 8.0}
+
         """
         c1034_list = self.get_all_item()
         # c104_list 내부에서는 항목, 전년/분기대비, 년/월을 포함하는 딕셔너리가 담겨있다.
@@ -559,8 +706,19 @@ class C1034(Corps):
 
     def find_cmp(self, title:str) -> float:
         """
-        타이틀에 해당하는 전년/분기대비 값을 반환한다.
-        *** 중복되는 title은 취급하지 않기로함...get_all_title()함수에서 정리함.
+
+        타이틀에 해당하는 전년/분기대비 값을 반환한다.\n
+        해당 타이틀이 없을 경우 - nan 반환함.\n
+
+        Args:
+            title (str): 찾고자 하는 타이틀
+
+        Returns:
+            float: 전년/분기대비 증감율
+
+        Note:
+            중복되는 title 은 취급하지 않기로함.\n
+            get_all_title()함수에서 중복 타이틀 정리함.\n
         """
         try:
             return self.get_all_cmp()[title]
@@ -569,17 +727,41 @@ class C1034(Corps):
 
     def find(self, title: str) -> dict:
         """
-        타이틀에 해당하는 년도, 분기 딕셔너리를 반환한다.
-        *** 중복되는 title은 취급하지 않기로함...get_all_title()함수에서 정리함.
+
+        타이틀에 해당하는 년도, 분기 딕셔너리를 반환한다.\n
+        해당 타이틀이 없을 경우 - {} 반환함.\n
+
+        Args:
+            title (str): 찾고자 하는 타이틀
+
+        Returns:
+            dict: ex - {'2016/12': 51.9',...'2019/12': 4.2, '2020/12': 344.1, '2021/12': nan}
+
+        Note:
+            중복되는 title 은 취급하지 않기로함.\n
+            get_all_title()함수에서 중복 타이틀 정리함.\n
         """
         try:
             return self.get_all()[title]
         except KeyError:
             return {}
 
-    def sum_recent_4q(self, title: str) -> tuple:
-        """
-        c103q 또는 c104q 한정 해당 타이틀의 최근 4분기의 합을 (계산된 4분기 중 최근분기, 총합)의 튜플형식으로 반환한다.
+    def sum_recent_4q(self, title: str) -> Tuple[str, float]:
+        """최근 4분기 합
+
+        분기 페이지 한정 해당 타이틀의 최근 4분기의 합을 튜플 형식으로 반환한다.
+
+        Args:
+            title (str): 찾고자 하는 타이틀
+
+        Returns:
+            tuple: (계산된 4분기 중 최근분기, 총합)
+
+        Raises:
+            TypeError: 페이지가 q가 아닌 경우 발생
+
+        Note:
+            분기 데이터가 4개 이하인 경우 그냥 최근 연도의 값을 찾아 반환한다.
         """
         if self.col.endswith('q'):
             # 딕셔너리 정렬 - https://kkamikoon.tistory.com/138
@@ -597,15 +779,25 @@ class C1034(Corps):
                     d, v = od_q.popitem(last=True)
                     logger.debug(f'd:{d} v:{v}')
                     q_sum += 0 if math.isnan(v) else v
-                return last_date, round(q_sum, 2)
+                return str(last_date), round(q_sum, 2)
 
         else:
             raise TypeError(f'Not support year data..{self.col}')
 
-    def latest_value(self, title: str) -> tuple:
-        """
-        title 에 해당하는 가장 최근의 값을 ('2020/09', 39617.5)와 같은 튜플로 반환한다.
-        만약 값이 nan 이면 바로 직전 것을 한번만 더 찾아 본다.
+    def latest_value(self, title: str) -> Tuple[str, float]:
+        """가장 최근 년/분기 값
+
+        해당 타이틀의 가장 최근의 년/분기 값을 튜플 형식으로 반환한다.
+
+        Args:
+            title (str): 찾고자 하는 타이틀
+
+        Returns:
+            tuple: ex - ('2020/09', 39617.5) or ('', 0)
+
+        Note:
+            만약 최근 값이 nan 이면 찾은 값 바로 직전 것을 한번 더 찾아 본다.\n
+            데이터가 없는 경우 ('', 0) 반환한다.\n
         """
         # 딕셔너리 정렬 - https://kkamikoon.tistory.com/138
         # reverse = False 이면 오래된것부터 최근순으로 정렬한다.
@@ -615,41 +807,78 @@ class C1034(Corps):
             last_one = od.popitem(last=True)
         except KeyError:
             # when dictionary is empty
-            return None, 0
+            return '', 0
         logger.info(f'last_one : {last_one}')
         if isinstance(last_one[1], str):
             # last_one : ('Unnamed: 1', '데이터가 없습니다.') 인 경우
-            return None, 0
+            return '', 0
         elif math.isnan(last_one[1]):
             last_one = od.popitem(last=True)
             if last_one is None:
-                return None, 0
+                return '', 0
         return tuple(last_one)
 
 
 class C104(C1034):
-    def __init__(self, code: str, page: str):
+    """C104 컬렉션 관련 클래스
+    """
+    def __init__(self, code: str, page: str = 'c104y'):
+        """
+
+        Args:
+            code (str): 종목코드(디비명)
+            page (str): c104y, c104q(컬렉션명)
+        """
         super().__init__(code=code, page=page)
 
     def save(self, c104_list: list) -> bool:
-        """
-        - 인자 c103 리스트 형식
-         [{'항목': '자산총계', '2020/03': 3574575.4, ... '전분기대비': 3.9},
-         {'항목': '유동자산', '2020/03': 1867397.5, ... '전분기대비': 5.5}]
-        - 항목이 중복되는 경우가 있기 때문에 각 항목을 키로하는 딕셔너리로 만들지 않는다..
+        """데이터베이스에 저장
+
+        c104는 4페이지의 자료를 한 컬렉션에 모으는 것이기 때문에
+        stamp 를 검사하여 12시간 전보다 이전에 저장된 자료가 있으면
+        삭제한 후 저장하고 12시간 이내의 자료는 삭제하지 않고
+        데이터를 추가하는 형식으로 저장한다.
+
+        Args:
+            c104_list (list): 딕셔너리를 담은 리스트 형식
+
+        Returns:
+            bool: 저장 성공 실패 여부
+
+        Example:
+            c104_list 예시\n
+            [{'항목': '매출액증가율',...'2020/12': 2.78, '2021/12': 14.9, '전년대비': 8.27, '전년대비1': 12.12},
+            {'항목': '영업이익증가율',...'2020/12': 29.62, '2021/12': 43.86, '전년대비': 82.47, '전년대비1': 14.24}]
+
+        Note:
+            항목이 중복되는 경우가 있기 때문에 c104처럼 각 항목을 키로하는 딕셔너리로 만들지 않는다.
         """
         time_now = datetime.datetime.now()
-        c104_list.append({'stamp': time_now})  # c104가 리스트라서 append 사용
-        # c104는 4페이지의 자료를 한 컬렉션에 모으는 것이기 때문에 stamp를 검사하여 12시간전보다 이전에 저장된 자료가 있으면 삭제한 후
-        # 저장하고 12시간 이내의 자료는 삭제하지 않고 데이터를 추가하는 형식으로 저장한다.
+        # c104가 리스트라서 append 사용
+        c104_list.append({'stamp': time_now})
         if self.client[self.db][self.col].find_one({'stamp': {'$lt': time_now - datetime.timedelta(days=.5)}}):
-            self.client[self.db][self.col].delete_many({})  # delete all documents in a collection
+            # delete all documents in a collection
+            self.client[self.db][self.col].delete_many({})
         result = self.client[self.db][self.col].insert_many(c104_list)
         return result.acknowledged
 
 
 class C103(C1034):
-    def __init__(self, code: str, page: str):
+    """C103 컬렉션 관련 클래스
+    """
+    def __init__(self, code: str, page: str = 'c103재무상태표y'):
+        """
+
+        Args:
+            code (str): 종목코드(디비명)
+            page (str): 페이지명(컬렉션명)
+
+        Example:
+            c103손익계산서q (c103손q, c103iq, c103_iq)\n
+            c103재무상태표y (c103재q, c103bq, c103_bq)\n
+            c103현금흐름표q (c103현q, c103cq, c103_cq)\n
+
+        """
         if page.startswith('c103') and page[-1] in ['q', 'y']:
             if page[4:-1] in ['손익계산서', '손', 'i', '_i']:
                 super().__init__(code=code, page=''.join([page[:4], '손익계산서', page[-1]]))
@@ -676,11 +905,21 @@ class C103(C1034):
             raise ValueError(f'Invalid value : {page}')
 
     def save(self, c103_list: list) -> bool:
-        """
-        - 인자 c103 리스트 형식
-         [{'항목': '자산총계', '2020/03': 3574575.4, ... '전분기대비': 3.9},
-         {'항목': '유동자산', '2020/03': 1867397.5, ... '전분기대비': 5.5}]
-        - 항목이 중복되는 경우가 있기 때문에 각 항목을 키로하는 딕셔너리로 만들지 않는다..
+        """데이터베이스에 저장
+
+        Args:
+            c103_list (list): 딕셔너리를 담은 리스트 형식
+
+        Returns:
+            bool: 저장 성공 실패 여부
+
+        Example:
+            c103_list 예시\n
+            [{'항목': '자산총계', '2020/03': 3574575.4, ... '전분기대비': 3.9},
+            {'항목': '유동자산', '2020/03': 1867397.5, ... '전분기대비': 5.5}]
+
+        Note:
+            항목이 중복되는 경우가 있기 때문에 c104처럼 각 항목을 키로하는 딕셔너리로 만들지 않는다.
         """
         c103_list.append({'stamp': datetime.datetime.now()})  # c103가 리스트라서 append 사용
         # delete all documents in a collection
@@ -695,13 +934,18 @@ class Noti(Base):
 
     def save(self, noti_dict: dict) -> bool:
         """
-        noti_dict 구조
-        {'code': '005930',
-        'rcept_no': '20210514000624',
-        'rcept_dt': '20210514',
-        'report_nm': '임원ㆍ주요주주특정증권등소유상황보고서',
-        'point': 2,
-        'text': '등기임원이 1.0억 이상 구매하지 않음.'}
+
+        Args:
+            noti_dict (dict) : dart 에서 전달되는 딕셔너리 구조
+
+        Note:
+            noti_dict 구조\n
+            {'code': '005930',\n
+            'rcept_no': '20210514000624',\n
+            'rcept_dt': '20210514',\n
+            'report_nm': '임원ㆍ주요주주특정증권등소유상황보고서',\n
+            'point': 2,\n
+            'text': '등기임원이 1.0억 이상 구매하지 않음.'}\n
         """
         self.client[self.db][self.col].delete_many({'rcept_no': {"$eq": noti_dict['rcept_no']}})
         result = self.client[self.db][self.col].insert_one(noti_dict)
@@ -714,7 +958,12 @@ class Noti(Base):
             df = DataFrame()
         return df
 
-    def cleaning_data(self, days_ago=15):
+    def cleaning_data(self, days_ago: int = 15):
+        """
+
+        days_ago 인자를 기준으로 이전 날짜의 데이터를 검색하여 삭제한다.
+        본 함수를 주기적으로 실행해 준다.
+        """
         border_date_str = (datetime.datetime.today() - datetime.timedelta(days=days_ago)).strftime('%Y%m%d')
         try:
             self.client[self.db][self.col].delete_many({'rcept_dt': {'$lt': border_date_str}})
