@@ -8,7 +8,7 @@ formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
 ch = logging.StreamHandler()
 ch.setFormatter(formatter)
 logger.addHandler(ch)
-logger.setLevel(logging.ERROR)
+logger.setLevel(logging.WARNING)
 
 DEF_MONGO_ADDR = 'mongodb://localhost:27017'
 DEF_WIN_SQLITE3_PATH = 'C:\\_db'
@@ -38,26 +38,30 @@ def load() -> dict:
             return p_dict
 
 
-def chg_mongo_addr(addr: str) -> dict:
-    if not addr.startswith('mongodb://'):
-        raise ValueError(f'Invalid mongo address : {addr}')
-    else:
+def chg_mongo_addr(addr: str):
+    if addr == '' or addr.startswith('mongodb://'):
         p_dict = load()
+        before = p_dict['mongo']
         p_dict['mongo'] = addr
+        if before != addr:
+            logger.info(f'Change mongo setting : {before} -> {addr}')
         with open(FULL_PATH, "wb") as fw:
             pickle.dump(p_dict, fw)
-        return load()
+    else:
+        raise ValueError(f'Invalid mongo address : {addr}')
 
 
-def chg_sqlite3_path(path: str) -> dict:
+def chg_sqlite3_path(path: str):
     p_dict = load()
+    before = p_dict['sqlite3']
     p_dict['sqlite3'] = path
+    if before != path:
+        logger.info(f'Change mongo setting : {before} -> {path}')
     with open(FULL_PATH, "wb") as fw:
         pickle.dump(p_dict, fw)
-    return load()
 
 
-def set_default() -> dict:
+def set_default():
     pickle_dict = {'mongo': DEF_MONGO_ADDR, 'sqlite3': ''}
     if 'Windows' in platform.platform():
         pickle_dict['sqlite3'] = DEF_WIN_SQLITE3_PATH
@@ -67,4 +71,3 @@ def set_default() -> dict:
         raise
     with open(FULL_PATH, "wb") as fw:
         pickle.dump(pickle_dict, fw)
-    return pickle_dict
