@@ -233,11 +233,11 @@ class Base:
         meta.reflect(bind=self.engine)
         return tuple(meta.tables.keys())
 
-    def _get_session(self):
+    def _get_session(self, base_cla):
         if self.engine is None:
             return None
         else:
-            BaseCorps.metadata.create_all(self.engine)
+            base_cla.metadata.create_all(self.engine)
             Session = sessionmaker(bind=self.engine)
             return Session()
 
@@ -253,7 +253,7 @@ class Corps(Base):
             self.code = code
             self.table = table
             super().__init__(folder_name='corps', db_name=self.code)
-            self.session = self._get_session()
+            self.session = self._get_session(BaseCorps)
         else:
             raise ValueError(f'Invalid value : {code}(6 digit) / {table}({self.TABLE})')
 
@@ -264,7 +264,7 @@ class Corps(Base):
         if utils.is_6digit(code):
             logger.info(f'Set db : {self.code} -> {code}')
             self.code = code
-            self.session = self._get_session()
+            self.session = self._get_session(BaseCorps)
         else:
             raise ValueError(f'Invalid value : {code}(6 digit)')
 
@@ -332,7 +332,7 @@ class C101(Corps):
 
 
 class C103(Corps):
-    def __init__(self, code: str, page: str):
+    def __init__(self, code: str, page: str = 'c103재무상태표y'):
         if page.startswith('c103') and page[-1] in ['q', 'y']:
             if page[4:-1] in ['손익계산서', '손', 'i', '_i']:
                 super().__init__(code=code, table=''.join([page[:4], '손익계산서', page[-1]]))
@@ -357,7 +357,7 @@ class C103(Corps):
 
 
 class C104(Corps):
-    def __init__(self, code: str, page: str):
+    def __init__(self, code: str, page: str = 'c104y'):
         super().__init__(code=code, table=page)
 
     def save(self, c104_df: pd.DataFrame) -> bool:
@@ -374,7 +374,7 @@ class C104(Corps):
 class C106(Corps):
     PERIOD = ['q', 'y']
 
-    def __init__(self, code: str, page: str):
+    def __init__(self, code: str, page: str = 'c106y'):
         if page[:4] == 'c106' and page[4:5] in self.PERIOD:
             super().__init__(code=code, table=page)
             self.page = page
@@ -420,9 +420,7 @@ class MI(Base):
             # 테이블명에 해당하는 클래스를 할당하기 위해 첫글자를 대문자로 바꿔서 능동적으로 클래스를 할당한다.
             self.tabls_cls = globals()[index.capitalize()]
             super().__init__(folder_name='mi', db_name='mi')
-            BaseMI.metadata.create_all(self.engine)
-            Session = sessionmaker(bind=self.engine)
-            self.session = Session()
+            self.session = self._get_session(BaseMI)
         else:
             raise ValueError(f'Invalid value : {index} / {self.TABLE}')
 
@@ -462,9 +460,7 @@ class Noti(Base):
     def __init__(self):
         self.table = NotiStructure.__tablename__
         super().__init__(folder_name='noti', db_name='noti')
-        BaseNoti.metadata.create_all(self.engine)
-        Session = sessionmaker(bind=self.engine)
-        self.session = Session()
+        self.session = self._get_session(BaseNoti)
 
     def save(self, noti_dict: dict) -> bool:
         """
